## Introduction
This project is based on the open source project [inih](https://github.com/benhoyt/inih), which is used to parse the .cfg format configuration file of ArduCam.

Note: arducam_config_parser.py is a python wrapper for dynamic libraries. To use it, you need to install the dynamic library first.

### Built
```
cd src
make clean && make
```

### Installation
`sudo make install`